
What is Tox?
--------------------

Tox as is a generic virtualenv management and test command line tool you can use for:

* checking your package installs correctly with different Python versions and
  interpreters

* running your tests in each of the environments, configuring your test tool of choice

* acting as a frontend to Continuous Integration servers, greatly
  reducing boilerplate and merging CI and shell-based testing.

For more information and the repository please checkout:

- homepage: http://tox.testrun.org

- repository: https://bitbucket.org/hpk42/tox


have fun,

holger krekel, 2014

